@@ -5,19 +5,27 @@ Analyze docstrings to detect errors.
 Call ``validate(object_name_to_validate)`` to get a dictionary
 with all the detected errors.
 """
+
+from copy import deepcopy
+from typing import Dict, List, Set, Optional
 import ast
 import collections
+import functools
 import importlib
 import inspect
+import os
 import pydoc
 import re
 import textwrap
+import tokenize
+
 from .docscrape import get_doc_object
 
 
 DIRECTIVES = ["versionadded", "versionchanged", "deprecated"]
-DIRECTIVE_PATTERN = re.compile(r"^\s*\.\. ({})(?!::)".format('|'.join(DIRECTIVES)),
-                               re.I | re.M)
+DIRECTIVE_PATTERN = re.compile(
+    r"^\s*\.\. ({})(?!::)".format("|".join(DIRECTIVES)), re.I | re.M
+)
 ALLOWED_SECTIONS = [
     "Parameters",
     "Attributes",
@@ -33,67 +41,151 @@ ALLOWED_SECTIONS = [
     "References",
     "Examples",
 ]
+# NOTE: The following comment is a sentinel for embedding in the docs - do not
+# modify/remove
+# start-err-msg
 ERROR_MSGS = {
     "GL01": "Docstring text (summary) should start in the line immediately "
-            "after the opening quotes (not in the same line, or leaving a "
-            "blank line in between)",
+    "after the opening quotes (not in the same line, or leaving a "
+    "blank line in between)",
     "GL02": "Closing quotes should be placed in the line after the last text "
-            "in the docstring (do not close the quotes in the same line as "
-            "the text, or leave a blank line between the last text and the "
-            "quotes)",
+    "in the docstring (do not close the quotes in the same line as "
+    "the text, or leave a blank line between the last text and the "
+    "quotes)",
     "GL03": "Double line break found; please use only one blank line to "
-            "separate sections or paragraphs, and do not leave blank lines "
-            "at the end of docstrings",
+    "separate sections or paragraphs, and do not leave blank lines "
+    "at the end of docstrings",
     "GL05": 'Tabs found at the start of line "{line_with_tabs}", please use '
-            "whitespace only",
+    "whitespace only",
     "GL06": 'Found unknown section "{section}". Allowed sections are: '
-            "{allowed_sections}",
+    "{allowed_sections}",
     "GL07": "Sections are in the wrong order. Correct order is: {correct_sections}",
     "GL08": "The object does not have a docstring",
     "GL09": "Deprecation warning should precede extended summary",
     "GL10": "reST directives {directives} must be followed by two colons",
     "SS01": "No summary found (a short summary in a single line should be "
-            "present at the beginning of the docstring)",
+    "present at the beginning of the docstring)",
     "SS02": "Summary does not start with a capital letter",
     "SS03": "Summary does not end with a period",
     "SS04": "Summary contains heading whitespaces",
     "SS05": "Summary must start with infinitive verb, not third person "
-            '(e.g. use "Generate" instead of "Generates")',
+    '(e.g. use "Generate" instead of "Generates")',
     "SS06": "Summary should fit in a single line",
     "ES01": "No extended summary found",
     "PR01": "Parameters {missing_params} not documented",
     "PR02": "Unknown parameters {unknown_params}",
     "PR03": "Wrong parameters order. Actual: {actual_params}. "
-            "Documented: {documented_params}",
+    "Documented: {documented_params}",
     "PR04": 'Parameter "{param_name}" has no type',
     "PR05": 'Parameter "{param_name}" type should not finish with "."',
     "PR06": 'Parameter "{param_name}" type should use "{right_type}" instead '
-            'of "{wrong_type}"',
+    'of "{wrong_type}"',
     "PR07": 'Parameter "{param_name}" has no description',
     "PR08": 'Parameter "{param_name}" description should start with a '
-            "capital letter",
+    "capital letter",
     "PR09": 'Parameter "{param_name}" description should finish with "."',
     "PR10": 'Parameter "{param_name}" requires a space before the colon '
-            "separating the parameter name and type",
+    "separating the parameter name and type",
     "RT01": "No Returns section found",
     "RT02": "The first line of the Returns section should contain only the "
-            "type, unless multiple values are being returned",
+    "type, unless multiple values are being returned",
     "RT03": "Return value has no description",
     "RT04": "Return value description should start with a capital letter",
     "RT05": 'Return value description should finish with "."',
     "YD01": "No Yields section found",
     "SA01": "See Also section not found",
     "SA02": "Missing period at end of description for See Also "
-            '"{reference_name}" reference',
+    '"{reference_name}" reference',
     "SA03": "Description should be capitalized for See Also "
-            '"{reference_name}" reference',
+    '"{reference_name}" reference',
     "SA04": 'Missing description for See Also "{reference_name}" reference',
     "EX01": "No examples section found",
 }
+# end-err-msg
+# NOTE: The above comment is a sentinel for embedding in the docs - do not
+# modify/remove
 
 # Ignore these when evaluating end-of-line-"." checks
 IGNORE_STARTS = (" ", "* ", "- ")
 
+# inline comments that can suppress individual checks per line
+IGNORE_COMMENT_PATTERN = re.compile("(?:.* numpydoc ignore[=|:] ?)(.+)")
+
+
+# This function gets called once per function/method to be validated.
+# We have to balance memory usage with performance here. It shouldn't be too
+# bad to store these `dict`s (they should be rare), but to be safe let's keep
+# the limit low-ish. This was set by looking at scipy, numpy, matplotlib,
+# and pandas and they had between ~500 and ~1300 .py files as of 2023-08-16.
+@functools.lru_cache(maxsize=2000)
+def extract_ignore_validation_comments(
+    filepath: Optional[os.PathLike],
+) -> Dict[int, List[str]]:
+    """
+    Extract inline comments indicating certain validation checks should be ignored.
+
+    Parameters
+    ----------
+    filepath : os.PathLike
+        Path to the file being inspected.
+
+    Returns
+    -------
+    dict[int, list[str]]
+        Mapping of line number to a list of checks to ignore.
+    """
+    numpydoc_ignore_comments = {}
+    try:
+        file = open(filepath)
+    except (OSError, TypeError):  # can be None, nonexistent, or unreadable
+        return numpydoc_ignore_comments
+    with file:
+        last_declaration = 1
+        declarations = ["def", "class"]
+        for token in tokenize.generate_tokens(file.readline):
+            if token.type == tokenize.NAME and token.string in declarations:
+                last_declaration = token.start[0]
+            if token.type == tokenize.COMMENT:
+                match = re.match(IGNORE_COMMENT_PATTERN, token.string)
+                if match:
+                    rules = match.group(1).split(",")
+                    numpydoc_ignore_comments[last_declaration] = rules
+    return numpydoc_ignore_comments
+
+
+def get_validation_checks(validation_checks: Set[str]) -> Set[str]:
+    """
+    Get the set of validation checks to report on.
+
+    Parameters
+    ----------
+    validation_checks : set[str]
+        A set of validation checks to report on. If the set is ``{"all"}``,
+        all checks will be reported. If the set contains just specific checks,
+        only those will be reported on. If the set contains both ``"all"`` and
+        specific checks, all checks except those included in the set will be
+        reported on.
+
+    Returns
+    -------
+    set[str]
+        The set of validation checks to report on.
+    """
+    valid_error_codes = set(ERROR_MSGS.keys())
+    if "all" in validation_checks:
+        block = deepcopy(validation_checks)
+        validation_checks = valid_error_codes - block
+
+    # Ensure that the validation check set contains only valid error codes
+    invalid_error_codes = validation_checks - valid_error_codes
+    if invalid_error_codes:
+        raise ValueError(
+            f"Unrecognized validation code(s) in numpydoc_validation_checks "
+            f"config value: {invalid_error_codes}"
+        )
+
+    return validation_checks
+
 
 def error(code, **kwargs):
     """
@@ -133,7 +225,7 @@ class Validator:
 
     @property
     def name(self):
-        return '.'.join([self.obj.__module__, self.obj.__name__])
+        return ".".join([self.obj.__module__, self.obj.__name__])
 
     @staticmethod
     def _load_obj(name):
@@ -164,7 +256,7 @@ class Validator:
             else:
                 break
         else:
-            raise ImportError(f"No module can be imported from \"{name}\"")
+            raise ImportError(f'No module can be imported from "{name}"')
 
         for part in func_parts:
             obj = getattr(obj, part)
@@ -188,7 +280,13 @@ class Validator:
         File name where the object is implemented (e.g. pandas/core/frame.py).
         """
         try:
-            fname = inspect.getsourcefile(self.code_obj)
+            if isinstance(self.code_obj, property):
+                fname = inspect.getsourcefile(self.code_obj.fget)
+            elif isinstance(self.code_obj, functools.cached_property):
+                fname = inspect.getsourcefile(self.code_obj.func)
+            else:
+                fname = inspect.getsourcefile(self.code_obj)
+
         except TypeError:
             # In some cases the object is something complex like a cython
             # object that can't be easily introspected. An it's better to
@@ -203,7 +301,22 @@ class Validator:
         Number of line where the object is defined in its file.
         """
         try:
-            return inspect.getsourcelines(self.code_obj)[-1]
+            if isinstance(self.code_obj, property):
+                sourcelines = inspect.getsourcelines(self.code_obj.fget)
+            elif isinstance(self.code_obj, functools.cached_property):
+                sourcelines = inspect.getsourcelines(self.code_obj.func)
+            else:
+                sourcelines = inspect.getsourcelines(self.code_obj)
+            # getsourcelines will return the line of the first decorator found for the
+            # current function. We have to find the def declaration after that.
+            def_line = next(
+                i
+                for i, x in enumerate(
+                    re.match("^ *(def|class) ", s) for s in sourcelines[0]
+                )
+                if x is not None
+            )
+            return sourcelines[-1] + def_line
         except (OSError, TypeError):
             # In some cases the object is something complex like a cython
             # object that can't be easily introspected. An it's better to
@@ -323,7 +436,7 @@ class Validator:
     def parameter_mismatches(self):
         errs = []
         signature_params = self.signature_parameters
-        all_params = tuple(self.doc_all_parameters)
+        all_params = tuple(param.replace("\\", "") for param in self.doc_all_parameters)
         missing = set(signature_params) - set(all_params)
         if missing:
             errs.append(error("PR01", missing_params=str(missing)))
@@ -438,13 +551,12 @@ def _check_desc(desc, code_no_desc, code_no_upper, code_no_period, **kwargs):
             errs.append(error(code_no_upper, **kwargs))
         # Not ending in "." is only an error if the last bit is not
         # indented (e.g., quote or code block)
-        if not desc[-1].endswith(".") and \
-                not desc[-1].startswith(IGNORE_STARTS):
+        if not desc[-1].endswith(".") and not desc[-1].startswith(IGNORE_STARTS):
             errs.append(error(code_no_period, **kwargs))
     return errs
 
 
-def validate(obj_name):
+def validate(obj_name, validator_cls=None, **validator_kwargs):
     """
     Validate the docstring.
 
@@ -455,6 +567,11 @@ def validate(obj_name):
         'pandas.read_csv'. The string must include the full, unabbreviated
         package/module names, i.e. 'pandas.read_csv', not 'pd.read_csv' or
         'read_csv'.
+    validator_cls : Validator, optional
+        The Validator class to use. By default, :class:`Validator` will be used.
+    **validator_kwargs
+        Keyword arguments to pass to ``validator_cls`` upon initialization.
+        Note that ``obj_name`` will be passed as a named argument as well.
 
     Returns
     -------
@@ -487,14 +604,24 @@ def validate(obj_name):
     they are validated, are not documented more than in the source code of this
     function.
     """
-    if isinstance(obj_name, str):
-        doc = Validator(get_doc_object(Validator._load_obj(obj_name)))
+    if not validator_cls:
+        if isinstance(obj_name, str):
+            doc = Validator(get_doc_object(Validator._load_obj(obj_name)))
+        else:
+            doc = Validator(obj_name)
     else:
-        doc = Validator(obj_name)
+        doc = validator_cls(obj_name=obj_name, **validator_kwargs)
+
+    # lineno is only 0 if we have a module docstring in the file and we are
+    # validating that, so we change to 1 for readability of the output
+    ignore_validation_comments = extract_ignore_validation_comments(
+        doc.source_file_name
+    ).get(doc.source_file_def_line or 1, [])
 
     errs = []
     if not doc.raw_doc:
-        errs.append(error("GL08"))
+        if "GL08" not in ignore_validation_comments:
+            errs.append(error("GL08"))
         return {
             "type": doc.type,
             "docstring": doc.clean_doc,
@@ -578,7 +705,7 @@ def validate(obj_name):
                     ("string", "str"),
                 ]
                 for wrong_type, right_type in common_type_errors:
-                    if wrong_type in doc.parameter_type(param):
+                    if wrong_type in set(re.split(r"\W", doc.parameter_type(param))):
                         errs.append(
                             error(
                                 "PR06",
@@ -587,8 +714,7 @@ def validate(obj_name):
                                 wrong_type=wrong_type,
                             )
                         )
-        errs.extend(_check_desc(
-            kind_desc[1], "PR07", "PR08", "PR09", param_name=param))
+        errs.extend(_check_desc(kind_desc[1], "PR07", "PR08", "PR09", param_name=param))
 
     if doc.is_function_or_method:
         if not doc.returns:
@@ -617,6 +743,9 @@ def validate(obj_name):
 
     if not doc.examples:
         errs.append(error("EX01"))
+
+    errs = [err for err in errs if err[0] not in ignore_validation_comments]
+
     return {
         "type": doc.type,
         "docstring": doc.clean_doc,
